@@ -68,6 +68,8 @@ class TicTacToe:
         self.play()
         
     def play_again(self):
+        import sys
+        
         while True:
             question = input("Do you want to play again?\n Type y or n \n")
             if question == 'y':
@@ -77,7 +79,7 @@ class TicTacToe:
                 self.run()
             elif question == 'n':
                 print("See you next time!")
-                quit()
+                sys.exit()
             else:
                 print("That's not a valid answer.")
              
